@@ -40,6 +40,46 @@ from ._jsii import *
 import aws_cdk
 import aws_cdk.cx_api
 import cdk_nag
+import constructs
+
+
+class AwsPrototypingChecks(
+    cdk_nag.NagPack,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-prototyping-sdk/pdk-nag.AwsPrototypingChecks",
+):
+    '''Check best practices for prototypes.'''
+
+    def __init__(
+        self,
+        *,
+        log_ignores: typing.Optional[builtins.bool] = None,
+        reports: typing.Optional[builtins.bool] = None,
+        verbose: typing.Optional[builtins.bool] = None,
+    ) -> None:
+        '''
+        :param log_ignores: Whether or not to log triggered rules that have been suppressed as informational messages (default: false).
+        :param reports: Whether or not to generate CSV compliance reports for applied Stacks in the App's output directory (default: true).
+        :param verbose: Whether or not to enable extended explanatory descriptions on warning, error, and logged ignore messages (default: false).
+        '''
+        props = cdk_nag.NagPackProps(
+            log_ignores=log_ignores, reports=reports, verbose=verbose
+        )
+
+        jsii.create(self.__class__, self, [props])
+
+    @jsii.member(jsii_name="visit")
+    def visit(self, node: constructs.IConstruct) -> None:
+        '''Check if CfnResource and apply rules.
+
+        :param node: -
+        '''
+        if __debug__:
+            def stub(node: constructs.IConstruct) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument node", value=node, expected_type=type_hints["node"])
+        return typing.cast(None, jsii.invoke(self, "visit", [node]))
 
 
 @jsii.data_type(
@@ -621,6 +661,7 @@ class PDKNagAppProps(aws_cdk.AppProps):
 
 
 __all__ = [
+    "AwsPrototypingChecks",
     "Message",
     "NagResult",
     "PDKNag",
